veloxml.core package
====================

Submodules
----------

veloxml.core.c\_veloxml\_core module
------------------------------------

.. automodule:: veloxml.core.c_veloxml_core
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: veloxml.core
   :members:
   :show-inheritance:
   :undoc-members:
